// Ionic Starter App

angular.module('underscore', [])
.factory('_', function() {
  return window._; // assumes underscore has already been loaded on the page
});

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
angular.module('your_app_name', [
  'ionic',
  'angularMoment',
  'your_app_name.controllers',
  'your_app_name.directives',
  'your_app_name.filters',
  'your_app_name.services',
  'your_app_name.factories',
  'your_app_name.config',
  'your_app_name.views',
  'underscore',
  //'ngMap',
  'ngResource',
  'ngCordova',
  'slugifier',
  //'ionic.contrib.ui.tinderCards',
  //'youtube-embed'
])

.run(function($ionicPlatform, PushNotificationsService, $rootScope, $ionicConfig, $timeout) {

  $ionicPlatform.ready(function() {
    // Enable to debug issues.
    // window.plugins.OneSignal.setLogLevel({logLevel: 4, visualLevel: 4});
    var notificationOpenedCallback = function(jsonData) {
      console.log('notificationOpenedCallback: ' + JSON.stringify(jsonData));
    };

    window.plugins.OneSignal
        .startInit("834204e9-f76f-4b5e-99b9-c28fa5f7b2fd")
        .handleNotificationOpened(notificationOpenedCallback)
        .endInit();
    // Call syncHashedEmail anywhere in your app if you have the user's email.
    // This improves the effectiveness of OneSignal's "best-time" notification scheduling feature.
    // window.plugins.OneSignal.syncHashedEmail(userEmail);
  });

  $ionicPlatform.on("deviceready", function(){
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)


    if(window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
    if(window.StatusBar) {
      StatusBar.styleDefault();
    }
    PushNotificationsService.register();
  });

  // This fixes transitions for transparent background views
  $rootScope.$on("$stateChangeStart", function(event, toState, toParams, fromState, fromParams){
    if(toState.name.indexOf('auth.walkthrough') > -1)
    {
      // set transitions to android to avoid weird visual effect in the walkthrough transitions
      $timeout(function(){
        $ionicConfig.views.transition('android');
        $ionicConfig.views.swipeBackEnabled(false);
      	console.log("setting transition to android and disabling swipe back");
      }, 0);
    }
  });
  $rootScope.$on("$stateChangeSuccess", function(event, toState, toParams, fromState, fromParams){
    if(toState.name.indexOf('app.feeds-categories') > -1)
    {
      // Restore platform default transition. We are just hardcoding android transitions to auth views.
      $ionicConfig.views.transition('platform');
      // If it's ios, then enable swipe back again
      if(ionic.Platform.isIOS())
      {
        $ionicConfig.views.swipeBackEnabled(true);
      }
    	console.log("enabling swipe back and restoring transition to platform default", $ionicConfig.views.transition());
    }
  });

  $ionicPlatform.on("resume", function(){
    PushNotificationsService.register();
  });

})


.config(function($stateProvider, $urlRouterProvider, $ionicConfigProvider) {
  $stateProvider

  .state('app', {
    url: "/app",
    abstract: true,
    templateUrl: "views/app/side-menu.html",
    controller: 'AppCtrl'
  })

  .state('app.home', {
    url: "/home",
    views: {
      'menuContent': {
        templateUrl: "views/app/home.html",
        controller: 'HomeCtrl'
      }
    }
  })

  .state('app.search', {
    url: "/search",
    views: {
      'menuContent': {
        templateUrl: "views/app/search.html",
        controller: 'SearchCtrl'
      }
    }
  })

  //LAYOUTS
  .state('app.layouts', {
    url: "/layouts",
    views: {
      'menuContent': {
        templateUrl: "views/app/layouts/layouts.html"
      }
    }
  })

  //FEEDS
  .state('app.feeds-categories', {
    url: "/feeds-categories",
    views: {
      'menuContent': {
        templateUrl: "views/app/feeds/feeds-categories.html",
        controller: 'FeedsCategoriesCtrl'
      }
    }
  })

  .state('app.category-feeds', {
    url: "/category-feeds/:categoryId/:categoryName",
    views: {
      'menuContent': {
        templateUrl: "views/app/feeds/category-feeds.html",
        controller: 'CategoryFeedsCtrl'
      }
    }
  })

  .state('app.feed-entries', {
    url: "/feed-entries/:categoryId/:sourceId",
    views: {
      'menuContent': {
        templateUrl: "views/app/feeds/feed-entries.html",
        controller: 'FeedEntriesCtrl'
      }
    }
  })

  .state('app.product', {
    url: '/product/:prdId',
    views: {
      'menuContent': {
        templateUrl: "views/app/feeds/product.html",
        controller: 'productCtrl'
      }
    }
  })

  .state('app.partner_cats', {
    url: "/partner_category",
    views: {
      'menuContent': {
        templateUrl: "views/app/partners/partner_cats.html",
        controller: 'PartnerCategoriesCtrl'
      }
    }
  })

  .state('app.cats_partner', {
    url: "/cats_partner/:categoryId/:categoryName",
    views: {
      'menuContent': {
        templateUrl: "views/app/partners/cats_partner.html",
        controller: 'CategoryPartnerCtrl'
      }
    }
  })

  .state('app.partner', {
    url: '/partner/:partnerId',
    views: {
      'menuContent': {
        templateUrl: "views/app/partners/partner.html",
        controller: 'PartnerCtrl'
      }
    }
  })

  .state('app.aboutus', {
    url: '/aboutus',
    views: {
      'menuContent': {
        templateUrl: "views/app/profile.html",
        controller: 'AboutUsCtrl'
      }
    }
  })
  .state('app.contactus', {
    url: '/contactus',
    views: {
      'menuContent': {
        templateUrl: "views/app/contactus.html",
        controller: 'ContactUsCtrl'
      }
    }
  })

  .state('app.service_cats', {
    url: "/service_category",
    views: {
      'menuContent': {
        templateUrl: "views/app/services/service_cats.html",
        controller: 'ServiceCategoriesCtrl'
      }
    }
  })

  .state('app.cats_service', {
    url: "/cats_service/:categoryId/:categoryName",
    views: {
      'menuContent': {
        templateUrl: "views/app/services/cats_service.html",
        controller: 'CategoryServiceCtrl'
      }
    }
  })

  .state('app.service', {
    url: '/service/:serviceId',
    views: {
      'menuContent': {
        templateUrl: "views/app/services/service.html",
        controller: 'ServiceCtrl'
      }
    }
  })

  //News
  .state('app.wordpress', {
    url: "/wordpress",
    views: {
      'menuContent': {
        templateUrl: "views/app/wordpress/wordpress.html",
        controller: 'NewsCtrl'
      }
    }
  })

  .state('app.post', {
    url: "/wordpress/:postId",
    views: {
      'menuContent': {
        templateUrl: "views/app/wordpress/wordpress_post.html",
        controller: 'NewsPostCtrl'
      }
    },
    resolve: {
      post_data: function(PostService, $ionicLoading, $stateParams) {
        $ionicLoading.show({
      		template: 'Loading post ...'
      	});

        var postId = $stateParams.postId;
        return PostService.getPost(postId);
      }
    }
  })

  .state('app.forms', {
    url: "/forms",
    views: {
      'menuContent': {
        templateUrl: "views/app/guaranty/forms.html",
        controller: 'InquiryCtrl'
      }
    }
  })

  .state('app.profile', {
    url: "/profile",
    views: {
      'menuContent': {
        templateUrl: "views/app/profile.html"
      }
    }
  })

/*   .state('app.barcode', {
    url: "/barcode",
    views: {
      'menuContent': {
        templateUrl: "views/app/barcode/barcode.html",
        controller: 'BarcodeCtrl'
      }
    }
  }) */

;

  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/app/home');
});
